@@ -32,13 +32,14 @@ from testflows._core.funcs import top, current, previous, load, append_path
 from testflows._core.funcs import main, args, private_key
 from testflows._core.funcs import metric, ticket, value, note, debug, trace
 from testflows._core.funcs import attribute, requirement, tag
+from testflows._core.funcs import input
 from testflows._core.funcs import message, exception, ok, fail, skip, err
-from testflows._core.funcs import null, xok, xfail, xerr, xnull, pause, getsattr
+from testflows._core.funcs import result, null, xok, xfail, xerr, xnull, pause, getsattr
 from testflows._core.funcs import current_dir, current_module, load_module
 from testflows._core.flags import TE, UT, SKIP, EOK, EFAIL, EERROR, ESKIP
 from testflows._core.flags import XOK, XFAIL, XERROR, XNULL
 from testflows._core.flags import FAIL_NOT_COUNTED, ERROR_NOT_COUNTED, NULL_NOT_COUNTED
-from testflows._core.flags import PAUSE, PAUSE_BEFORE, PAUSE_AFTER, REPORT, DOCUMENT
+from testflows._core.flags import PAUSE, PAUSE_BEFORE, PAUSE_AFTER, REPORT, DOCUMENT, MANUAL
 from testflows._core.flags import MANDATORY, CLEAR
 from testflows._core.flags import EANY, ERESULT, XRESULT
 from testflows._core import __author__, __version__, __license__
